from math import sqrt
import matplotlib

golden_ratio = (sqrt(5)-1.0)/2.0    # Aesthetic ratio

def latexify(fig_width=None, fig_height=None):
    """Set up matplotlib's RC params for LaTeX plotting.
    Call this before plotting a figure.

    Parameters
    ----------
    fig_width : float, optional, inches
    fig_height : float,  optional, inches
    columns : {1, 2}
    """

    # code adapted from http://www.scipy.org/Cookbook/Matplotlib/LaTeX_Examples

    if fig_width is None:
        fig_width = 5  # width in inches

    if fig_height is None:
        fig_height = fig_width*golden_ratio # height in inches


    # params = {'backend': 'ps',
    #           'text.latex.preamble': [r"\usepackage{gensymb} \usepackage{amsmath}"],
    #           'axes.labelsize': 10, # fontsize for x and y labels
    #           'axes.titlesize': 12,
    #           'legend.fontsize': 10, # was 10
    #           'xtick.labelsize': 10,
    #           'ytick.labelsize': 10,
    #           'text.usetex': True,
    #           'figure.figsize': [fig_width, fig_height],
    #           'font.family': 'serif'
    # }

    params = {'backend': 'ps',
              'text.latex.preamble': [r"\usepackage{amsmath}"],
              'axes.labelsize': 8, # fontsize for x and y labels
              'axes.titlesize': 10,
              'legend.fontsize': 8, # was 10
              'xtick.labelsize': 8,
              'ytick.labelsize': 8,
              'text.usetex': True,
              'figure.figsize': [fig_width, fig_height],
              'font.family': 'serif',
              'lines.markersize': 6 * fig_width / 5,       # scale relative to default figwidth
              'lines.linewidth': 1.5 * fig_width / 5,       # scale relative to default figwidth
    }


    # params = {'backend': 'ps',
    #           'text.latex.preamble': [r"\usepackage{gensymb} \usepackage{amsmath}"],
    #           'axes.labelsize': 12, # fontsize for x and y labels
    #           'axes.titlesize': 12,
    #           'legend.fontsize': 10, # was 10
    #           'xtick.labelsize': 12,
    #           'ytick.labelsize': 12,
    #           'text.usetex': True,
    #           'figure.figsize': [fig_width, fig_height],
    #           'font.family': 'serif'
    # }
    matplotlib.rcParams.update(params)
    
